import React from "react";
import { SearchResultsStore } from "searchResults/domain/searchStore";
import { changeSearchRequestUseCase } from "searchResults/useCases/changeSearchRequestUseCase";
import { searchUseCase } from "searchResults/useCases/searchUseCase";

function useSearchViewModel(store: SearchResultsStore) {
  const search = React.useCallback(
    function () {
      return searchUseCase({
        searchResults: store.searchResults,
        searchRequest: store.searchRequest,
        search: store.search,
      });
    },
    [store.searchRequest, store.search, store.searchResults]
  );

  const changeSearchRequest = React.useCallback(
    function (searchRequest: string) {
      return changeSearchRequestUseCase({
        searchRequest: searchRequest,
        changeSearchRequest: store.changeSearchRequest,
      });
    },
    [store.searchRequest, store.changeSearchRequest]
  );

  return {
    searchResults: store.searchResults,
    searchRequest: store.searchRequest,
    failure: store.failure,
    isLoading: store.isLoading,
    isFailed: store.isFailed,
    search,
    changeSearchRequest,
  };
}
export { useSearchViewModel };
