import React from "react";
import { SearchResultsStore } from "searchResults/domain/searchStore";
import { RootState, useAppDispatch, useAppSelector } from "store";
import { SearchAction } from "./actions/searchActions";
import { SearchStoreState } from "./searchReducer";

const searchSelector = (state: RootState): SearchStoreState =>
  state.searchResults;

const useSearchStoreImplementation = (): SearchResultsStore => {
  const { searchResults, failure, isFailed, isLoading, request } =
    useAppSelector(searchSelector);

  const dispatch = useAppDispatch();

  const search = React.useCallback(
    (query: string) => SearchAction(request)(dispatch),
    [dispatch]
  );

  return {
    request,
    isLoading,
    isFailed,
    searchResults,
    failure,
    search: search,
  };
};

export { useSearchStoreImplementation };
